/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.macro.script;

import java.util.Collections;

import org.jmock.Expectations;
import org.jmock.Mockery;
import org.jmock.integration.junit4.JUnit4Mockery;
import org.junit.runner.RunWith;
import org.xwiki.component.descriptor.DefaultComponentDescriptor;
import org.xwiki.component.manager.ComponentManager;
import org.xwiki.observation.EventListener;
import org.xwiki.observation.event.Event;
import org.xwiki.rendering.test.integration.RenderingTestSuite;
import org.xwiki.rendering.transformation.MacroTransformationContext;
import org.xwiki.script.event.ScriptEvaluatingEvent;

/**
 * Run all tests found in {@code *.test} files located in the classpath. These {@code *.test} files must follow the
 * conventions described in {@link org.xwiki.rendering.test.integration.TestDataParser}.
 *
 * @version $Id: 04a4dc27cfe37a8e2b061dec20e1928ce614cceb $
 * @since 3.0RC1
 */
@RunWith(RenderingTestSuite.class)
public class IntegrationTests
{
    @RenderingTestSuite.Initialized
    public void initialize(ComponentManager componentManager) throws Exception
    {
        Mockery mockery = new JUnit4Mockery();
        new ScriptMockSetup(mockery, componentManager);

        // fake nested script validator never fails
        final EventListener nestedValidator
            = mockery.mock(EventListener.class, "nestedscriptmacrovalidator");
        mockery.checking(new Expectations() {{
            atLeast(1).of(nestedValidator).onEvent(with(any(Event.class)), with(any(MacroTransformationContext.class)),
                with(any(ScriptMacroParameters.class)));
            allowing(nestedValidator).getName();
                will(returnValue("nestedscriptmacrovalidator"));
            allowing(nestedValidator).getEvents();
                will(returnValue(Collections.singletonList((Event) new ScriptEvaluatingEvent())));
        }});
        DefaultComponentDescriptor<EventListener> validatorDescriptor
            = new DefaultComponentDescriptor<EventListener>();
        validatorDescriptor.setRole(EventListener.class);
        validatorDescriptor.setRoleHint("nestedscriptmacrovalidator");
        componentManager.registerComponent(validatorDescriptor, nestedValidator);
    }
}
