/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.url.internal.standard;

import org.xwiki.component.annotation.Component;
import org.xwiki.component.annotation.Requirement;
import org.xwiki.configuration.ConfigurationSource;
import org.xwiki.url.standard.StandardURLConfiguration;

/**
 * @version $Id: 9eb7a3d014792bd584a73643ab9c5b3bef7681f0 $
 * @since 2.3M1
 */
@Component
public class DefaultStandardURLConfiguration implements StandardURLConfiguration
{
    /**
     * Prefix for configuration keys for the Core module.
     */
    private static final String PREFIX = "url.standard.";

    /**
     * Defines from where to read the URL configuration data.
     */
    @Requirement("xwikiproperties")
    private ConfigurationSource configuration;

    /**
     * {@inheritDoc}
     * @see org.xwiki.url.standard.StandardURLConfiguration#isPathBasedMultiWiki()
     */
    public boolean isPathBasedMultiWiki()
    {
        return this.configuration.getProperty(PREFIX + "multiwiki.isPathBased", Boolean.FALSE);
    }

    /**
     * {@inheritDoc}
     * @see StandardURLConfiguration#getWikiPathPrefix()
     */
    public String getWikiPathPrefix()
    {
        return this.configuration.getProperty(PREFIX + "multiwiki.wikiPathPrefix", "wiki");
    }
}
